# Roasset
An Wrapper for Roblox Web Asset Api.

## Example:
```py
import roasset
url = roasset.Asset.assetloc(6209211782)
print(url)
```


### Installation:
`pip install -U git+https://github.com/Hxnter69/Roasset.git`
